@@ -41,9 +41,11 @@ private:
     k9DrawImage *m_wimage;
     QTime m_timer;
     Ui::MP4Dlg Ui_MP4Dlg;
+    bool m_showImage;
 protected slots:
   /*$PROTECTED_FUNCTIONS$*/
   void Cancel();
+  void bPlayToggled(bool _state);
 
 };
 
