@@ -51,8 +51,8 @@ void _k9CheckListItem::stateChange(bool _state) {
 }
 
 
-k9MencoderCmdGen::k9MencoderCmdGen(QWidget* parent,const QString &_cmd)
-: QDialog(parent)
+k9MencoderCmdGen::k9MencoderCmdGen(QWidget* parent,const QString &_cmd,const QString &_encoder)
+: QDialog(parent),m_encoder(_encoder)
 {
     Ui_mencoderCmdGen.setupUi(this);
     Ui_mencoderCmdGen.buttonOk->setGuiItem(KStandardGuiItem::Ok);
@@ -154,7 +154,7 @@ void k9MencoderCmdGen::listViewCurrentChanged(QTreeWidgetItem *_item,QTreeWidget
 }
 
 void k9MencoderCmdGen::loadXml() {
-    QFile file(KGlobal::dirs()->findResource( "data", "k9copy/mencoder.xml"));
+    QFile file(KGlobal::dirs()->findResource( "data", QString("k9copy/%1.xml").arg(m_encoder)));
     if ( !file.open( QIODevice::ReadOnly ) )
         return;
     if ( !m_doc.setContent( &file ) ) {
@@ -578,8 +578,8 @@ const QString & k9MencoderCmdGen::getCmd(const QString &_root) {
     return m_cmd;
 }
 
-bool k9MencoderCmdGen::getMencoderOptions(QString &_cmd) {
-    k9MencoderCmdGen * m_cmdGen=new k9MencoderCmdGen(NULL,_cmd);
+bool k9MencoderCmdGen::getMencoderOptions(QString &_cmd,const QString &_encoder) {
+    k9MencoderCmdGen * m_cmdGen=new k9MencoderCmdGen(NULL,_cmd,_encoder);
     m_cmdGen->m_cmd=_cmd;
     bool res=m_cmdGen->exec();
     if (res) {
@@ -591,6 +591,7 @@ bool k9MencoderCmdGen::getMencoderOptions(QString &_cmd) {
         if (!m_audio.isEmpty())
             m_audio="-oac " +m_audio;
         _cmd=" "+m_video+" "+m_audio+" "+m_filters;
+	_cmd=_cmd.trimmed();
     }
     delete m_cmdGen;
     return res;
